==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/id-ID/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Tentang Aset',
    'about_assets_text'            => 'Aset adalah barang yang dilacak dengan nomor seri atau tanda aset. Cenderung menjadi barang dengan nilai lebih tinggi dimana identifikasi barang secara spesifik berpengaruh.',
    'archived'  				=> 'Diarsipkan',
    'asset'  					=> 'Aset',
    'bulk_checkout'             => 'Pengeluaran Aset',
    'bulk_checkin'              => 'Tandai Aset Masuk ',
    'checkin'  					=> 'Pengembalian aset',
    'checkout'  				=> 'Aset Checkout',
    'clone'  					=> 'Klon Aset',
    'deployable'  				=> 'Dapat digunakan',
    'deleted'  					=> 'Aset ini telah dihapus.',
    'delete_confirm'            => 'Apakah Anda yakin ingin menghapus aset ini?',
    'edit'  					=> 'Sunting Aset',
    'model_deleted'  			=> 'Model Aset ini telah dihapus. Anda harus memulihkan model aset tersebut sebelum Anda dapat memulihkan Aset.',
    'model_invalid'             => 'Model untuk aset ini tidak valid.',
    'model_invalid_fix'         => 'Aset harus diperbarui menggunakan model aset yang valid sebelum dicoba untuk dikembalikan atau dipinjam, atau diaudit.',
    'requestable'               => 'Dapat diminta',
    'requested'				    => 'Telah diminta',
    'not_requestable'           => 'Tidak Dapat Diminta',
    'requestable_status_warning' => ' Jangan ubah status permintaan.',
    'restore'  					=> 'Mengembalikan aset',
    'pending'  					=> 'Tunda',
    'undeployable'  			=> 'Tidak dapat digunakan',
    'undeployable_tooltip'  	=> 'Aset ini memiliki label status yang tidak dapat digunakan dan tidak dapat dipinjam/diambil saat ini.',
    'view'  					=> 'Tampilkan aset',
    'csv_error' => 'Anda memiliki kesalahan dalam file: CSV Anda',
    'import_text' => '<p>Unggah CSV yang berisi riwayat aset. Aset dan pengguna HARUS sudah ada di sistem, atau akan dilewati. Pencocokan aset untuk impor riwayat dilakukan berdasarkan tag aset. Kami akan mencoba mencari pengguna yang cocok berdasarkan nama pengguna yang Anda berikan, dan kriteria yang Anda pilih di bawah. Jika Anda tidak memilih kriteria apa pun di bawah, sistem hanya akan mencoba mencocokkan format nama pengguna yang Anda konfigurasi di <code>Admin &gt; Pengaturan Umum</code>.</p><p>Kolom yang disertakan dalam CSV harus sesuai dengan header: <strong>Tag Aset, Nama, Tanggal Pinjam, Tanggal Kembali</strong>. Kolom tambahan apa pun akan diabaikan.</p><p>Tanggal Kembali: tanggal kembali yang kosong atau di masa mendatang akan meminjamkan item ke pengguna terkait. Mengesampingkan kolom Tanggal Kembali akan membuat tanggal kembali dengan tanggal hari ini.</p>    ',
    'csv_import_match_f-l' => 'Coba cocokkan pengguna berdasarkan format <strong>nama_depan.nama_belakang</strong> (<code>jane.smith</code>)',
    'csv_import_match_initial_last' => 'Coba cocokkan pengguna berdasarkan format <strong>inisial nama depan nama belakang</strong> (<code>jsmith</code>)',
    'csv_import_match_first' => 'Coba cocokkan pengguna berdasarkan format <strong>nama depan</strong> (<code>jane</code>)',
    'csv_import_match_email' => 'Coba cocokkan pengguna berdasarkan <strong>email</strong> sebagai nama pengguna',
    'csv_import_match_username' => 'Coba cocokkan pengguna berdasarkan <strong>nama pengguna</strong>',
    'error_messages' => 'Pesan kesalahan:',
    'success_messages' => 'Pesan keberhasilan:',
    'alert_details' => 'Silakan lihat di bawah untuk detailnya.',
    'custom_export' => 'Ekspor Kustom',
    'mfg_warranty_lookup' => 'Pencarian Status Garansi :manufacturer',
    'user_department' => 'Departemen Pengguna',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/id-ID/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Tentang Aset',
    'about_assets_text'            => 'Aset adalah barang yang dilacak dengan nomor seri atau tanda aset. Cenderung menjadi barang dengan nilai lebih tinggi dimana identifikasi barang secara spesifik berpengaruh.',
    'archived'  				=> 'Diarsipkan',
    'asset'  					=> 'Aset',
    'bulk_checkout'             => 'check-out masal',
    'bulk_checkin'              => 'Bulk Checkin',
    'checkin'  					=> 'Pengembalian aset',
    'checkout'  				=> 'Aset Checkout',
    'clone'  					=> 'Klon Aset',
    'deployable'  				=> 'Dapat digunakan',
    'deleted'  					=> 'Aset ini telah dihapus.',
    'delete_confirm'            => 'Apakah Anda yakin ingin menghapus aset ini?',
    'edit'  					=> 'Sunting Aset',
    'model_deleted'  			=> 'Model Aset ini telah dihapus. Anda harus memulihkan model aset tersebut sebelum Anda dapat memulihkan Aset.',
    'model_invalid'             => 'Model untuk aset ini tidak valid.',
    'model_invalid_fix'         => 'Aset harus diperbarui menggunakan model aset yang valid sebelum dicoba untuk dikembalikan atau dipinjam, atau diaudit.',
    'requestable'               => 'Dapat diminta',
    'requested'				    => 'Telah diminta',
    'not_requestable'           => 'Tidak Dapat Diminta',
    'requestable_status_warning' => ' Jangan ubah status permintaan.',
    'restore'  					=> 'Mengembalikan aset',
    'pending'  					=> 'Tunda',
    'undeployable'  			=> 'Tidak dapat digunakan',
    'undeployable_tooltip'  	=> 'Aset ini memiliki label status yang tidak dapat digunakan dan tidak dapat dipinjam/diambil saat ini.',
    'view'  					=> 'Tampilkan aset',
    'csv_error' => 'Anda memiliki kesalahan dalam file: CSV Anda',
    'import_text' => '<p>Unggah CSV yang berisi riwayat aset. Aset dan pengguna HARUS sudah ada di sistem, atau akan dilewati. Pencocokan aset untuk impor riwayat dilakukan berdasarkan tag aset. Kami akan mencoba mencari pengguna yang cocok berdasarkan nama pengguna yang Anda berikan, dan kriteria yang Anda pilih di bawah. Jika Anda tidak memilih kriteria apa pun di bawah, sistem hanya akan mencoba mencocokkan format nama pengguna yang Anda konfigurasi di <code>Admin &gt; Pengaturan Umum</code>.</p><p>Kolom yang disertakan dalam CSV harus sesuai dengan header: <strong>Tag Aset, Nama, Tanggal Pinjam, Tanggal Kembali</strong>. Kolom tambahan apa pun akan diabaikan.</p><p>Tanggal Kembali: tanggal kembali yang kosong atau di masa mendatang akan meminjamkan item ke pengguna terkait. Mengesampingkan kolom Tanggal Kembali akan membuat tanggal kembali dengan tanggal hari ini.</p>    ',
    'csv_import_match_f-l' => 'Coba cocokkan pengguna berdasarkan format <strong>nama_depan.nama_belakang</strong> (<code>jane.smith</code>)',
    'csv_import_match_initial_last' => 'Coba cocokkan pengguna berdasarkan format <strong>inisial nama depan nama belakang</strong> (<code>jsmith</code>)',
    'csv_import_match_first' => 'Coba cocokkan pengguna berdasarkan format <strong>nama depan</strong> (<code>jane</code>)',
    'csv_import_match_email' => 'Coba cocokkan pengguna berdasarkan <strong>email</strong> sebagai nama pengguna',
    'csv_import_match_username' => 'Coba cocokkan pengguna berdasarkan <strong>nama pengguna</strong>',
    'error_messages' => 'Pesan kesalahan:',
    'success_messages' => 'Pesan keberhasilan:',
    'alert_details' => 'Silakan lihat di bawah untuk detailnya.',
    'custom_export' => 'Ekspor Kustom',
    'mfg_warranty_lookup' => 'Pencarian Status Garansi :manufacturer',
    'user_department' => 'Departemen Pengguna',
];
